//#include <QtCharts/QColorBarAxis> // TODO : fix this
#include "colorbaraxis/qcolorbaraxis.h"
//#include <private/qcolorbaraxis_p.h>
#include "colorbaraxis/qcolorbaraxis_p.h"
#include <private/abstractdomain_p.h>
#include <private/chartdataset_p.h>
#include <private/chartpresenter_p.h>
#include <private/charttheme_p.h>

#include <QtGui>

QT_CHARTS_BEGIN_NAMESPACE


/*!
    Constructs an axis object which is a child of \a parent.
*/
QColorBarAxis::QColorBarAxis(QLinearGradient gradient, qreal min, qreal max,QObject *parent) :
    QAbstractAxis(*new QColorBarAxisPrivate(gradient, min, max, this), parent)
{

}

/*!
    \internal
*/
QColorBarAxis::QColorBarAxis(QColorBarAxisPrivate &d, QObject *parent)
    : QAbstractAxis(d, parent)
{

}

/*!
    Destroys the object
*/
QColorBarAxis::~QColorBarAxis()
{
    Q_D(QColorBarAxis);
    if (d->m_chart)
        d->m_chart->removeAxis(this);
}

qreal QColorBarAxis::min() const
{
    Q_D(const QColorBarAxis);
    return d->m_min;
}

qreal QColorBarAxis::max() const
{
    Q_D(const QColorBarAxis);
    return d->m_max;
}


//void QColorBarAxis::setTickCount(int count)
//{
//    Q_D(QColorBarAxis);
//    if (d->m_tickCount != count && count >= 2) {
//        d->m_tickCount = count;
//        emit tickCountChanged(count);
//    }
//}

//int QColorBarAxis::tickCount() const
//{
//    Q_D(const QColorBarAxis);
//    return d->m_tickCount;
//}

//void QColorBarAxis::setMinorTickCount(int count)
//{
//    Q_D(QColorBarAxis);
//    if (d->m_minorTickCount != count && count >= 0) {
//        d->m_minorTickCount = count;
//        emit minorTickCountChanged(count);
//    }
//}

//int QColorBarAxis::minorTickCount() const
//{
//    Q_D(const QColorBarAxis);
//    return d->m_minorTickCount;
//}

void QColorBarAxis::setLabelFormat(const QString &format)
{
    Q_D(QColorBarAxis);
    d->m_format = format;
    emit labelFormatChanged(format);
}

QString QColorBarAxis::labelFormat() const
{
    Q_D(const QColorBarAxis);
    return d->m_format;
}

/*!
  Returns the type of the axis
*/
QAbstractAxis::AxisType QColorBarAxis::type() const
{
    return AxisTypeValue;
    //TODO : AxisTypeColorBar
}

/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

QColorBarAxisPrivate::QColorBarAxisPrivate(QLinearGradient gradient, qreal min, qreal max, QColorBarAxis *q)
    : QAbstractAxisPrivate(q),
      m_min(min),
      m_max(max),
      //      m_tickCount(5),
      //      m_minorTickCount(0),
      m_format(QString::null),
    //      m_applying(false)
      m_gradient(gradient)
{

}

QColorBarAxisPrivate::~QColorBarAxisPrivate()
{

}

void QColorBarAxisPrivate::initializeGraphics(QGraphicsItem *parent)
{
    Q_Q(QColorBarAxis);
    ChartAxisElement *axis(0);

    setAlignment(Qt::AlignRight); //also set orientation (Vertical in this case)

    QGradientStops stops = m_gradient.stops();

    QLinearGradient gradient(0,0,1,250);
    foreach(QGradientStop stop, stops)
    {
        gradient.setColorAt(1-stop.first,stop.second);
    }

    QPixmap image = QPixmap(50,250);
    QPainter painter(&image);
    painter.fillRect(0,0,50,250,gradient);

    //m_item.reset(axis);
    QAbstractAxisPrivate::initializeGraphics(parent);
}

void QColorBarAxisPrivate::initializeDomain(AbstractDomain *domain)
{
    //domain is not supposed to have a rangeZ

    //    if (orientation() == Qt::Vertical) {
    //        if (!qFuzzyIsNull(m_max - m_min))
    //            domain->setRangeY(m_min, m_max);
    //        else
    //            setRange(domain->minY(), domain->maxY());
    //    }
    //    if (orientation() == Qt::Horizontal) {
    //        if (!qFuzzyIsNull(m_max - m_min))
    //            domain->setRangeX(m_min, m_max);
    //        else
    //            setRange(domain->minX(), domain->maxX());
    //    }
}


#include "moc_qcolorbaraxis.cpp"
#include "moc_qcolorbaraxis_p.cpp"

QT_CHARTS_END_NAMESPACE
